<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Vyžadován přístup správce</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Tato operace vyžaduje oprávnění správce. Restartujte aplikaci a po zobrazení výzvy zadejte heslo.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Byl detekován Live systém. Prosím zvolte root oddíl systému, který chcete upravit (zobrazeny jsou pouze Linux oddíly)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Použít zjednodušenou strukturu menu, bez podmenu.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Použít ploché menu (bez submenu)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Nabootovat do</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Pro vypnutí zobrazení bootovacího menu nastavte &apos;0&apos;, pro zrušení odpočtu zadejte &apos;-1&apos;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Odpočet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Parametry jádra</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>vteřiny</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Při této možnosti cokoliv co si vyberete v grub menu bude uloženo jako předvolená volba pro další přihlášení </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Zapnout ukládání poslední zvolené položky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Ovládat UEFI Možnosti </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Pozadí</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Povolit motivy</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Zprávy</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Velice detailní</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detailní (předvolené)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Omezené</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Display log</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Stále běží</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <location filename="../src/mainwindow.cpp" line="390"/>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <location filename="../src/mainwindow.cpp" line="535"/>
        <location filename="../src/mainwindow.cpp" line="1359"/>
        <location filename="../src/mainwindow.cpp" line="1372"/>
        <location filename="../src/mainwindow.cpp" line="1378"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instaluje se bootsplash, prosím vyčkejte</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="156"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>Updating sources</source>
        <translation>Aktualizace zdrojů</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="390"/>
        <source>Could not install the bootsplash.</source>
        <translation>Bootsplash se nepovedlo nainstalovat.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="535"/>
        <source>Could not create a temporary folder</source>
        <translation>Selhalo vytvoření dočasné složky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot continue</source>
        <translation>Nelze pokračovat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Nelze otevřít zařízení LUKS. Ukončování...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="565"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Nelze vytvořit chroot prostředí, nelze změnit možnosti bootování. Odchod...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="896"/>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Updating configuration, please wait</source>
        <translation>Aktualizace nastavení, prosím vydržte</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>Updating initramfs...</source>
        <translation>Aktualizace initramfs...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="981"/>
        <location filename="../src/mainwindow.cpp" line="1290"/>
        <source>Updating grub...</source>
        <translation>Aktualizace grub...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1006"/>
        <source>About %1</source>
        <translation>O programu %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1007"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1009"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program pro výběr možností zavedení systému.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1011"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1043"/>
        <location filename="../src/mainwindow.cpp" line="1252"/>
        <source>Running in a Virtual Machine</source>
        <translation>Běh pod Virtual Machine</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1044"/>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Systém jste spustili pod Virtual Machine,
Plymouth bootsplash  bude fungovat jenom omezeně, nebude možné motivy prohlížet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1051"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth není nainstalován</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1052"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth zatím není nainstalován.
Chcete pokračovat k instalaci?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1078"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Obrázky (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1220"/>
        <source>Log not found</source>
        <translation>Log nenalezen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1220"/>
        <source>Could not find log at </source>
        <translation>Nepodařilo se najít log v</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1359"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Nepodařilo se načíst UUID pro %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1367"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Zapsat heslo pro odemčení šifrovaného oddílu %1:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1372"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>Zadání hesla pro %1 bylo zrušeno nebo je prázdné</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1378"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Nelze otevřít kontejner %1 LUKS</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1209"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Proces stále běží. Opravdu chcete skončit?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="176"/>
        <source>Live System Detected</source>
        <translation>Detekován Live systém</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="178"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Momentálně používáte Live systém. Chcete upravit možnosti spouštění pro Live systém nebo pro nainstalovaný systém?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="180"/>
        <source>Live System</source>
        <translation>Live systém</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Installed System</source>
        <translation>Nainstalovaný systém</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <source>Failed to update package sources.</source>
        <translation>Nepodařilo se aktualizovat zdroje balíčků.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="386"/>
        <source>Installing packages:</source>
        <translation>Instalace balíčků:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash byl úspěšně nainstalován.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>Failed to create temporary file.</source>
        <translation>Nepodařilo se vytvořit dočasný soubor.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="989"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Momentálně používáte Live režim s volbou „toram“. Nezapomeňte si uložit soubor perzistence nebo remaster, jinak budou všechny provedené změny ztraceny.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="991"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Vaše změny byly úspěšně použity.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="992"/>
        <source>Operation Complete</source>
        <translation>Operace dokončena</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1077"/>
        <source>Select image to display in bootloader</source>
        <translation>Vybrat obrázek, který se zobrazí v pozadí</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1201"/>
        <source>Boot Log</source>
        <translation>Protokol spouštění</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1241"/>
        <source>Needs reboot</source>
        <translation>Potřebuje restart</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth lyl právě nainstalován, pro zobrazení náhledů bude možná nutný restart </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Click to select theme</source>
        <translation>Kliknout pro výběr motivu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1326"/>
        <source>Select GRUB theme</source>
        <translation>Vybrat motiv GRUBu</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program pro výběr možností zavedení systému.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
    </message>
</context>
</TS>